Class: Google::Apis::GkehubV1beta1::GKEHubService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::GkehubV1beta1::GKEHubService
- Defined in:
- lib/google/apis/gkehub_v1beta1/service.rb
Overview
GKE Hub API
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://gkehub.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_membership(parent, membership_object = nil, membership_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Operation
Creates a new Membership.
-
#delete_project_location_membership(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Operation
Removes a Membership.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Empty
Deletes a long-running operation.
-
#generate_project_location_membership_connect_manifest(name, connect_agent_name: nil, connect_agent_namespace: nil, connect_agent_proxy: nil, image_pull_secret_content: nil, is_upgrade: nil, registry: nil, version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::GenerateConnectManifestResponse
Generates the manifest for deployment of the GKE connect agent.
-
#generate_project_location_membership_exclusivity_manifest(name, cr_manifest: nil, crd_manifest: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::GenerateExclusivityManifestResponse
GenerateExclusivityManifest generates the manifests to update the exclusivity artifacts in the cluster if needed.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Location
Gets information about a location.
-
#get_project_location_membership(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Membership
Gets the details of a Membership.
-
#get_project_location_membership_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Policy
Gets the access control policy for a resource.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Operation
Gets the latest state of a long-running operation.
-
#initialize ⇒ GKEHubService
constructor
A new instance of GKEHubService.
-
#list_project_location_memberships(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::ListMembershipsResponse
Lists Memberships in a given project and location.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_membership(name, membership_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Operation
Updates an existing Membership.
-
#set_membership_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Policy
Sets the access control policy on the specified resource.
-
#test_membership_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#validate_project_location_membership_exclusivity(parent, cr_manifest: nil, intended_membership: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::ValidateExclusivityResponse
ValidateExclusivity validates the state of exclusivity in the cluster.
Constructor Details
#initialize ⇒ GKEHubService
Returns a new instance of GKEHubService.
47 48 49 50 51 52 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-gkehub_v1beta1', client_version: Google::Apis::GkehubV1beta1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
682 683 684 685 686 687 688 689 690 691 692 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 682 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:cancel', ) command.request_representation = Google::Apis::GkehubV1beta1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::GkehubV1beta1::Empty::Representation command.response_class = Google::Apis::GkehubV1beta1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_membership(parent, membership_object = nil, membership_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Operation
Creates a new Membership. This is currently only supported for GKE clusters on Google Cloud. To register other clusters, follow the instructions at https://cloud.google.com/anthos/multicluster-management/connect/registering-a- cluster.
182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 182 def create_project_location_membership(parent, membership_object = nil, membership_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/memberships', ) command.request_representation = Google::Apis::GkehubV1beta1::Membership::Representation command.request_object = membership_object command.response_representation = Google::Apis::GkehubV1beta1::Operation::Representation command.response_class = Google::Apis::GkehubV1beta1::Operation command.params['parent'] = parent unless parent.nil? command.query['membershipId'] = membership_id unless membership_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_membership(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Operation
Removes a Membership. This is currently only supported for GKE clusters on Google Cloud. To unregister other clusters, follow the instructions at https: //cloud.google.com/anthos/multicluster-management/connect/unregistering-a- cluster.
235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 235 def delete_project_location_membership(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::GkehubV1beta1::Operation::Representation command.response_class = Google::Apis::GkehubV1beta1::Operation command.params['name'] = name unless name.nil? command.query['force'] = force unless force.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
717 718 719 720 721 722 723 724 725 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 717 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::GkehubV1beta1::Empty::Representation command.response_class = Google::Apis::GkehubV1beta1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#generate_project_location_membership_connect_manifest(name, connect_agent_name: nil, connect_agent_namespace: nil, connect_agent_proxy: nil, image_pull_secret_content: nil, is_upgrade: nil, registry: nil, version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::GenerateConnectManifestResponse
Generates the manifest for deployment of the GKE connect agent. This method is used internally by Google-provided libraries. Most clients should not need to call this method directly.
294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 294 def generate_project_location_membership_connect_manifest(name, connect_agent_name: nil, connect_agent_namespace: nil, connect_agent_proxy: nil, image_pull_secret_content: nil, is_upgrade: nil, registry: nil, version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}:generateConnectManifest', ) command.response_representation = Google::Apis::GkehubV1beta1::GenerateConnectManifestResponse::Representation command.response_class = Google::Apis::GkehubV1beta1::GenerateConnectManifestResponse command.params['name'] = name unless name.nil? command.query['connectAgent.name'] = connect_agent_name unless connect_agent_name.nil? command.query['connectAgent.namespace'] = connect_agent_namespace unless connect_agent_namespace.nil? command.query['connectAgent.proxy'] = connect_agent_proxy unless connect_agent_proxy.nil? command.query['imagePullSecretContent'] = image_pull_secret_content unless image_pull_secret_content.nil? command.query['isUpgrade'] = is_upgrade unless is_upgrade.nil? command.query['registry'] = registry unless registry.nil? command.query['version'] = version unless version.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#generate_project_location_membership_exclusivity_manifest(name, cr_manifest: nil, crd_manifest: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::GenerateExclusivityManifestResponse
GenerateExclusivityManifest generates the manifests to update the exclusivity artifacts in the cluster if needed. Exclusivity artifacts include the Membership custom resource definition (CRD) and the singleton Membership custom resource (CR). Combined with ValidateExclusivity, exclusivity artifacts guarantee that a Kubernetes cluster is only registered to a single GKE Hub. The Membership CRD is versioned, and may require conversion when the GKE Hub API server begins serving a newer version of the CRD and corresponding CR. The response will be the converted CRD and CR if there are any differences between the versions.
347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 347 def generate_project_location_membership_exclusivity_manifest(name, cr_manifest: nil, crd_manifest: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}:generateExclusivityManifest', ) command.response_representation = Google::Apis::GkehubV1beta1::GenerateExclusivityManifestResponse::Representation command.response_class = Google::Apis::GkehubV1beta1::GenerateExclusivityManifestResponse command.params['name'] = name unless name.nil? command.query['crManifest'] = cr_manifest unless cr_manifest.nil? command.query['crdManifest'] = crd_manifest unless crd_manifest.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Location
Gets information about a location.
74 75 76 77 78 79 80 81 82 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 74 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::GkehubV1beta1::Location::Representation command.response_class = Google::Apis::GkehubV1beta1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_membership(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Membership
Gets the details of a Membership.
380 381 382 383 384 385 386 387 388 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 380 def get_project_location_membership(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::GkehubV1beta1::Membership::Representation command.response_class = Google::Apis::GkehubV1beta1::Membership command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_membership_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
424 425 426 427 428 429 430 431 432 433 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 424 def get_project_location_membership_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::GkehubV1beta1::Policy::Representation command.response_class = Google::Apis::GkehubV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
748 749 750 751 752 753 754 755 756 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 748 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::GkehubV1beta1::Operation::Representation command.response_class = Google::Apis::GkehubV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_memberships(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::ListMembershipsResponse
Lists Memberships in a given project and location.
474 475 476 477 478 479 480 481 482 483 484 485 486 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 474 def list_project_location_memberships(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/memberships', ) command.response_representation = Google::Apis::GkehubV1beta1::ListMembershipsResponse::Representation command.response_class = Google::Apis::GkehubV1beta1::ListMembershipsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
793 794 795 796 797 798 799 800 801 802 803 804 805 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 793 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}/operations', ) command.response_representation = Google::Apis::GkehubV1beta1::ListOperationsResponse::Representation command.response_class = Google::Apis::GkehubV1beta1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the [
ListLocationsRequest.name] field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 126 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}/locations', ) command.response_representation = Google::Apis::GkehubV1beta1::ListLocationsResponse::Representation command.response_class = Google::Apis::GkehubV1beta1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_membership(name, membership_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Operation
Updates an existing Membership.
524 525 526 527 528 529 530 531 532 533 534 535 536 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 524 def patch_project_location_membership(name, membership_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta1/{+name}', ) command.request_representation = Google::Apis::GkehubV1beta1::Membership::Representation command.request_object = membership_object command.response_representation = Google::Apis::GkehubV1beta1::Operation::Representation command.response_class = Google::Apis::GkehubV1beta1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_membership_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
563 564 565 566 567 568 569 570 571 572 573 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 563 def set_membership_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::GkehubV1beta1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::GkehubV1beta1::Policy::Representation command.response_class = Google::Apis::GkehubV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_membership_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
602 603 604 605 606 607 608 609 610 611 612 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 602 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::GkehubV1beta1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::GkehubV1beta1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::GkehubV1beta1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#validate_project_location_membership_exclusivity(parent, cr_manifest: nil, intended_membership: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::ValidateExclusivityResponse
ValidateExclusivity validates the state of exclusivity in the cluster. The validation does not depend on an existing Hub membership resource.
642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 642 def validate_project_location_membership_exclusivity(parent, cr_manifest: nil, intended_membership: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/memberships:validateExclusivity', ) command.response_representation = Google::Apis::GkehubV1beta1::ValidateExclusivityResponse::Representation command.response_class = Google::Apis::GkehubV1beta1::ValidateExclusivityResponse command.params['parent'] = parent unless parent.nil? command.query['crManifest'] = cr_manifest unless cr_manifest.nil? command.query['intendedMembership'] = intended_membership unless intended_membership.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |