Class: Google::Apis::GkehubV1beta1::Membership

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta1/classes.rb,
lib/google/apis/gkehub_v1beta1/representations.rb,
lib/google/apis/gkehub_v1beta1/representations.rb

Overview

Membership contains information about a member cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Membership

Returns a new instance of Membership.



887
888
889
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 887

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authorityGoogle::Apis::GkehubV1beta1::Authority

Authority encodes how Google will recognize identities from this Membership. See the workload identity documentation for more details: https://cloud.google. com/kubernetes-engine/docs/how-to/workload-identity Corresponds to the JSON property authority



792
793
794
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 792

def authority
  @authority
end

#create_timeString

Output only. When the Membership was created. Corresponds to the JSON property createTime

Returns:

  • (String)


797
798
799
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 797

def create_time
  @create_time
end

#delete_timeString

Output only. When the Membership was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


802
803
804
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 802

def delete_time
  @delete_time
end

#descriptionString

Optional. Description of this membership, limited to 63 characters. Must match the regex: a-zA-Z0-9* Corresponds to the JSON property description

Returns:

  • (String)


808
809
810
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 808

def description
  @description
end

#endpointGoogle::Apis::GkehubV1beta1::MembershipEndpoint

MembershipEndpoint contains information needed to contact a Kubernetes API, endpoint and any additional Kubernetes metadata. Corresponds to the JSON property endpoint



814
815
816
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 814

def endpoint
  @endpoint
end

#external_idString

Optional. An externally-generated and managed ID for this Membership. This ID may be modified after creation, but this is not recommended. For GKE clusters, external_id is managed by the Hub API and updates will be ignored. The ID must match the regex: a-zA-Z0-9* If this Membership represents a Kubernetes cluster, this value should be set to the UID of the kube-system namespace object. Corresponds to the JSON property externalId

Returns:

  • (String)


824
825
826
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 824

def external_id
  @external_id
end

#infrastructure_typeString

Optional. The infrastructure type this Membership is running on. Corresponds to the JSON property infrastructureType

Returns:

  • (String)


829
830
831
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 829

def infrastructure_type
  @infrastructure_type
end

#labelsHash<String,String>

Optional. GCP labels for this membership. These labels are not leveraged by multi-cluster features, instead, we prefer cluster labels, which can be set on GKE cluster or other cluster types. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


836
837
838
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 836

def labels
  @labels
end

#last_connection_timeString

Output only. For clusters using Connect, the timestamp of the most recent connection established with Google Cloud. This time is updated every several minutes, not continuously. For clusters that do not use GKE Connect, or that have never connected successfully, this field will be unset. Corresponds to the JSON property lastConnectionTime

Returns:

  • (String)


844
845
846
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 844

def last_connection_time
  @last_connection_time
end

#membership_typeString

Output only. The type of the membership. Corresponds to the JSON property membershipType

Returns:

  • (String)


849
850
851
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 849

def membership_type
  @membership_type
end

#monitoring_configGoogle::Apis::GkehubV1beta1::MonitoringConfig

MonitoringConfig informs Fleet-based applications/services/UIs how the metrics for the underlying cluster is reported to cloud monitoring services. It can be set from empty to non-empty, but can't be mutated directly to prevent accidentally breaking the constinousty of metrics. Corresponds to the JSON property monitoringConfig



857
858
859
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 857

def monitoring_config
  @monitoring_config
end

#nameString

Output only. The full, unique name of this Membership resource in the format projects/*/locations/*/memberships/membership_id`, set during creation. membership_idmust be a valid RFC 1123 compliant DNS label: 1. At most 63 characters in length 2. It must consist of lower case alphanumeric characters or-3. It must start and end with an alphanumeric character Which can be expressed as the regex:a-z0-9?, with a maximum length of 63 characters. Corresponds to the JSON propertyname`

Returns:

  • (String)


868
869
870
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 868

def name
  @name
end

#stateGoogle::Apis::GkehubV1beta1::MembershipState

State of the Membership resource. Corresponds to the JSON property state



873
874
875
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 873

def state
  @state
end

#unique_idString

Output only. Google-generated UUID for this resource. This is unique across all Membership resources. If a Membership resource is deleted and another resource with the same name is created, it gets a different unique_id. Corresponds to the JSON property uniqueId

Returns:

  • (String)


880
881
882
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 880

def unique_id
  @unique_id
end

#update_timeString

Output only. When the Membership was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


885
886
887
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 885

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 892

def update!(**args)
  @authority = args[:authority] if args.key?(:authority)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @description = args[:description] if args.key?(:description)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @external_id = args[:external_id] if args.key?(:external_id)
  @infrastructure_type = args[:infrastructure_type] if args.key?(:infrastructure_type)
  @labels = args[:labels] if args.key?(:labels)
  @last_connection_time = args[:last_connection_time] if args.key?(:last_connection_time)
  @membership_type = args[:membership_type] if args.key?(:membership_type)
  @monitoring_config = args[:monitoring_config] if args.key?(:monitoring_config)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @unique_id = args[:unique_id] if args.key?(:unique_id)
  @update_time = args[:update_time] if args.key?(:update_time)
end