Class: Google::Apis::GkehubV1beta1::MembershipEndpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta1/classes.rb,
lib/google/apis/gkehub_v1beta1/representations.rb,
lib/google/apis/gkehub_v1beta1/representations.rb

Overview

MembershipEndpoint contains information needed to contact a Kubernetes API, endpoint and any additional Kubernetes metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MembershipEndpoint

Returns a new instance of MembershipEndpoint.



954
955
956
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 954

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#appliance_clusterGoogle::Apis::GkehubV1beta1::ApplianceCluster

ApplianceCluster contains information specific to GDC Edge Appliance Clusters. Corresponds to the JSON property applianceCluster



919
920
921
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 919

def appliance_cluster
  @appliance_cluster
end

#edge_clusterGoogle::Apis::GkehubV1beta1::EdgeCluster

EdgeCluster contains information specific to Google Edge Clusters. Corresponds to the JSON property edgeCluster



924
925
926
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 924

def edge_cluster
  @edge_cluster
end

#gke_clusterGoogle::Apis::GkehubV1beta1::GkeCluster

GkeCluster contains information specific to GKE clusters. Corresponds to the JSON property gkeCluster



929
930
931
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 929

def gke_cluster
  @gke_cluster
end

#kubernetes_metadataGoogle::Apis::GkehubV1beta1::KubernetesMetadata

KubernetesMetadata provides informational metadata for Memberships representing Kubernetes clusters. Corresponds to the JSON property kubernetesMetadata



935
936
937
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 935

def 
  @kubernetes_metadata
end

#kubernetes_resourceGoogle::Apis::GkehubV1beta1::KubernetesResource

KubernetesResource contains the YAML manifests and configuration for Membership Kubernetes resources in the cluster. After CreateMembership or UpdateMembership, these resources should be re-applied in the cluster. Corresponds to the JSON property kubernetesResource



942
943
944
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 942

def kubernetes_resource
  @kubernetes_resource
end

#multi_cloud_clusterGoogle::Apis::GkehubV1beta1::MultiCloudCluster

MultiCloudCluster contains information specific to GKE Multi-Cloud clusters. Corresponds to the JSON property multiCloudCluster



947
948
949
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 947

def multi_cloud_cluster
  @multi_cloud_cluster
end

#on_prem_clusterGoogle::Apis::GkehubV1beta1::OnPremCluster

OnPremCluster contains information specific to GKE On-Prem clusters. Corresponds to the JSON property onPremCluster



952
953
954
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 952

def on_prem_cluster
  @on_prem_cluster
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



959
960
961
962
963
964
965
966
967
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 959

def update!(**args)
  @appliance_cluster = args[:appliance_cluster] if args.key?(:appliance_cluster)
  @edge_cluster = args[:edge_cluster] if args.key?(:edge_cluster)
  @gke_cluster = args[:gke_cluster] if args.key?(:gke_cluster)
  @kubernetes_metadata = args[:kubernetes_metadata] if args.key?(:kubernetes_metadata)
  @kubernetes_resource = args[:kubernetes_resource] if args.key?(:kubernetes_resource)
  @multi_cloud_cluster = args[:multi_cloud_cluster] if args.key?(:multi_cloud_cluster)
  @on_prem_cluster = args[:on_prem_cluster] if args.key?(:on_prem_cluster)
end