Class: Google::Apis::GkehubV1beta1::GKEHubService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::GkehubV1beta1::GKEHubService
- Defined in:
- lib/google/apis/gkehub_v1beta1/service.rb
Overview
GKE Hub API
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://gkehub.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_membership(parent, membership_object = nil, membership_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Operation
Creates a new Membership.
-
#delete_project_location_membership(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Operation
Removes a Membership.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Empty
Deletes a long-running operation.
-
#generate_project_location_membership_connect_manifest(name, connect_agent_name: nil, connect_agent_namespace: nil, connect_agent_proxy: nil, image_pull_secret_content: nil, is_upgrade: nil, registry: nil, version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::GenerateConnectManifestResponse
Generates the manifest for deployment of the GKE connect agent.
-
#generate_project_location_membership_exclusivity_manifest(name, cr_manifest: nil, crd_manifest: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::GenerateExclusivityManifestResponse
GenerateExclusivityManifest generates the manifests to update the exclusivity artifacts in the cluster if needed.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Location
Gets information about a location.
-
#get_project_location_membership(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Membership
Gets the details of a Membership.
-
#get_project_location_membership_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Policy
Gets the access control policy for a resource.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Operation
Gets the latest state of a long-running operation.
-
#initialize ⇒ GKEHubService
constructor
A new instance of GKEHubService.
-
#list_project_location_memberships(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::ListMembershipsResponse
Lists Memberships in a given project and location.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_membership(name, membership_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Operation
Updates an existing Membership.
-
#set_membership_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Policy
Sets the access control policy on the specified resource.
-
#test_membership_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#validate_project_location_membership_exclusivity(parent, cr_manifest: nil, intended_membership: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::ValidateExclusivityResponse
ValidateExclusivity validates the state of exclusivity in the cluster.
Constructor Details
#initialize ⇒ GKEHubService
Returns a new instance of GKEHubService.
47 48 49 50 51 52 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-gkehub_v1beta1', client_version: Google::Apis::GkehubV1beta1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
673 674 675 676 677 678 679 680 681 682 683 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 673 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:cancel', ) command.request_representation = Google::Apis::GkehubV1beta1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::GkehubV1beta1::Empty::Representation command.response_class = Google::Apis::GkehubV1beta1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_membership(parent, membership_object = nil, membership_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Operation
Creates a new Membership. This is currently only supported for GKE clusters on Google Cloud. To register other clusters, follow the instructions at https://cloud.google.com/anthos/multicluster-management/connect/registering-a- cluster.
173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 173 def create_project_location_membership(parent, membership_object = nil, membership_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/memberships', ) command.request_representation = Google::Apis::GkehubV1beta1::Membership::Representation command.request_object = membership_object command.response_representation = Google::Apis::GkehubV1beta1::Operation::Representation command.response_class = Google::Apis::GkehubV1beta1::Operation command.params['parent'] = parent unless parent.nil? command.query['membershipId'] = membership_id unless membership_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_membership(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Operation
Removes a Membership. This is currently only supported for GKE clusters on Google Cloud. To unregister other clusters, follow the instructions at https: //cloud.google.com/anthos/multicluster-management/connect/unregistering-a- cluster.
226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 226 def delete_project_location_membership(name, force: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::GkehubV1beta1::Operation::Representation command.response_class = Google::Apis::GkehubV1beta1::Operation command.params['name'] = name unless name.nil? command.query['force'] = force unless force.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
708 709 710 711 712 713 714 715 716 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 708 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::GkehubV1beta1::Empty::Representation command.response_class = Google::Apis::GkehubV1beta1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#generate_project_location_membership_connect_manifest(name, connect_agent_name: nil, connect_agent_namespace: nil, connect_agent_proxy: nil, image_pull_secret_content: nil, is_upgrade: nil, registry: nil, version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::GenerateConnectManifestResponse
Generates the manifest for deployment of the GKE connect agent. This method is used internally by Google-provided libraries. Most clients should not need to call this method directly.
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 285 def generate_project_location_membership_connect_manifest(name, connect_agent_name: nil, connect_agent_namespace: nil, connect_agent_proxy: nil, image_pull_secret_content: nil, is_upgrade: nil, registry: nil, version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}:generateConnectManifest', ) command.response_representation = Google::Apis::GkehubV1beta1::GenerateConnectManifestResponse::Representation command.response_class = Google::Apis::GkehubV1beta1::GenerateConnectManifestResponse command.params['name'] = name unless name.nil? command.query['connectAgent.name'] = connect_agent_name unless connect_agent_name.nil? command.query['connectAgent.namespace'] = connect_agent_namespace unless connect_agent_namespace.nil? command.query['connectAgent.proxy'] = connect_agent_proxy unless connect_agent_proxy.nil? command.query['imagePullSecretContent'] = image_pull_secret_content unless image_pull_secret_content.nil? command.query['isUpgrade'] = is_upgrade unless is_upgrade.nil? command.query['registry'] = registry unless registry.nil? command.query['version'] = version unless version.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#generate_project_location_membership_exclusivity_manifest(name, cr_manifest: nil, crd_manifest: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::GenerateExclusivityManifestResponse
GenerateExclusivityManifest generates the manifests to update the exclusivity artifacts in the cluster if needed. Exclusivity artifacts include the Membership custom resource definition (CRD) and the singleton Membership custom resource (CR). Combined with ValidateExclusivity, exclusivity artifacts guarantee that a Kubernetes cluster is only registered to a single GKE Hub. The Membership CRD is versioned, and may require conversion when the GKE Hub API server begins serving a newer version of the CRD and corresponding CR. The response will be the converted CRD and CR if there are any differences between the versions.
338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 338 def generate_project_location_membership_exclusivity_manifest(name, cr_manifest: nil, crd_manifest: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}:generateExclusivityManifest', ) command.response_representation = Google::Apis::GkehubV1beta1::GenerateExclusivityManifestResponse::Representation command.response_class = Google::Apis::GkehubV1beta1::GenerateExclusivityManifestResponse command.params['name'] = name unless name.nil? command.query['crManifest'] = cr_manifest unless cr_manifest.nil? command.query['crdManifest'] = crd_manifest unless crd_manifest.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Location
Gets information about a location.
74 75 76 77 78 79 80 81 82 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 74 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::GkehubV1beta1::Location::Representation command.response_class = Google::Apis::GkehubV1beta1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_membership(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Membership
Gets the details of a Membership.
371 372 373 374 375 376 377 378 379 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 371 def get_project_location_membership(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::GkehubV1beta1::Membership::Representation command.response_class = Google::Apis::GkehubV1beta1::Membership command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_membership_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
415 416 417 418 419 420 421 422 423 424 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 415 def get_project_location_membership_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::GkehubV1beta1::Policy::Representation command.response_class = Google::Apis::GkehubV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
739 740 741 742 743 744 745 746 747 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 739 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::GkehubV1beta1::Operation::Representation command.response_class = Google::Apis::GkehubV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_memberships(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::ListMembershipsResponse
Lists Memberships in a given project and location.
465 466 467 468 469 470 471 472 473 474 475 476 477 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 465 def list_project_location_memberships(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/memberships', ) command.response_representation = Google::Apis::GkehubV1beta1::ListMembershipsResponse::Representation command.response_class = Google::Apis::GkehubV1beta1::ListMembershipsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
784 785 786 787 788 789 790 791 792 793 794 795 796 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 784 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}/operations', ) command.response_representation = Google::Apis::GkehubV1beta1::ListOperationsResponse::Representation command.response_class = Google::Apis::GkehubV1beta1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::ListLocationsResponse
Lists information about the supported locations for this service.
117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 117 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}/locations', ) command.response_representation = Google::Apis::GkehubV1beta1::ListLocationsResponse::Representation command.response_class = Google::Apis::GkehubV1beta1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_membership(name, membership_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Operation
Updates an existing Membership.
515 516 517 518 519 520 521 522 523 524 525 526 527 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 515 def patch_project_location_membership(name, membership_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta1/{+name}', ) command.request_representation = Google::Apis::GkehubV1beta1::Membership::Representation command.request_object = membership_object command.response_representation = Google::Apis::GkehubV1beta1::Operation::Representation command.response_class = Google::Apis::GkehubV1beta1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_membership_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
554 555 556 557 558 559 560 561 562 563 564 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 554 def set_membership_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::GkehubV1beta1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::GkehubV1beta1::Policy::Representation command.response_class = Google::Apis::GkehubV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_membership_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
593 594 595 596 597 598 599 600 601 602 603 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 593 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::GkehubV1beta1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::GkehubV1beta1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::GkehubV1beta1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#validate_project_location_membership_exclusivity(parent, cr_manifest: nil, intended_membership: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV1beta1::ValidateExclusivityResponse
ValidateExclusivity validates the state of exclusivity in the cluster. The validation does not depend on an existing Hub membership resource.
633 634 635 636 637 638 639 640 641 642 643 |
# File 'lib/google/apis/gkehub_v1beta1/service.rb', line 633 def validate_project_location_membership_exclusivity(parent, cr_manifest: nil, intended_membership: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/memberships:validateExclusivity', ) command.response_representation = Google::Apis::GkehubV1beta1::ValidateExclusivityResponse::Representation command.response_class = Google::Apis::GkehubV1beta1::ValidateExclusivityResponse command.params['parent'] = parent unless parent.nil? command.query['crManifest'] = cr_manifest unless cr_manifest.nil? command.query['intendedMembership'] = intended_membership unless intended_membership.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |