Class: Google::Apis::GkehubV1beta1::ValidateExclusivityResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta1/classes.rb,
lib/google/apis/gkehub_v1beta1/representations.rb,
lib/google/apis/gkehub_v1beta1/representations.rb

Overview

The response of exclusivity artifacts validation result status.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ValidateExclusivityResponse

Returns a new instance of ValidateExclusivityResponse.



1550
1551
1552
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 1550

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#statusGoogle::Apis::GkehubV1beta1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



1548
1549
1550
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 1548

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1555
1556
1557
# File 'lib/google/apis/gkehub_v1beta1/classes.rb', line 1555

def update!(**args)
  @status = args[:status] if args.key?(:status)
end